# coding: utf-8

"""
    RTU MIREA VUC

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.1.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from schedule_service_client.models.workbook_file import WorkbookFile  # noqa: E501

class TestWorkbookFile(unittest.TestCase):
    """WorkbookFile unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WorkbookFile:
        """Test WorkbookFile
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WorkbookFile`
        """
        model = WorkbookFile()  # noqa: E501
        if include_optional:
            return WorkbookFile(
                course = None,
                workbook_path = None,
                worksheet_settings_path = None,
                worksheet_settings = {
                    'key' : schedule_service_client.models.worksheet_settings.WorksheetSettings(
                        day_range = null, 
                        year_range = null, 
                        days_in_week_column_number = null, 
                        platoon_column_number = null, 
                        subject_rows_number = null, )
                    }
            )
        else:
            return WorkbookFile(
                course = None,
                workbook_path = None,
                worksheet_settings_path = None,
                worksheet_settings = {
                    'key' : schedule_service_client.models.worksheet_settings.WorksheetSettings(
                        day_range = null, 
                        year_range = null, 
                        days_in_week_column_number = null, 
                        platoon_column_number = null, 
                        subject_rows_number = null, )
                    },
        )
        """

    def testWorkbookFile(self):
        """Test WorkbookFile"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
